# -*- coding: utf-8 -*-

from django.conf import settings
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from thx.core.admin import UserAdminMixin

from .models import SectionSettings, LabelTagSettings

from .utils import get_settings


class SectionAdminMixin(UserAdminMixin):
    fieldsets = (
        (_('general information'), {
            'fields': ('status', 'title', 'slug', 'template_name')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    prepopulated_fields = {'slug': ('title',)}

    def get_fieldsets(self, request, obj=None):
        try:
            return get_settings(obj.template_name, 'SECTION', 'ADMIN')
        except Exception as e:
            return super().get_fieldsets(request, obj)
        
    def get_form(self, request, obj=None, **kwargs):
        form = super().get_form(request, obj, **kwargs)
        self.set_field_image_cropping(form, obj)
        self.set_field_mobile_image_cropping(form, obj)
        return form

    def set_field_image_cropping(self, form, obj=None):
        if obj:
            try:
                size = get_settings(obj.template_name, 'SECTION', 'CROPPING')
                form.base_fields['image_cropping'].widget.attrs['data-min-width'] = size.split('x')[0]
                form.base_fields['image_cropping'].widget.attrs['data-min-height'] = size.split('x')[1]
                form.base_fields['image_cropping'].widget.attrs['data-ratio'] = \
                    int(size.split('x')[0]) / int(size.split('x')[1])
                return form
            except Exception as exc:
                pass
    
    def set_field_mobile_image_cropping(self, form, obj=None):
        if obj:
            try:
                size_mobile = get_settings(obj.template_name, 'SECTION', 'CROPPING_MOBILE')
                form.base_fields['mobile_image_cropping'].widget.attrs['data-min-width'] = size_mobile.split('x')[0]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-min-height'] = size_mobile.split('x')[1]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-ratio'] = \
                    int(size_mobile.split('x')[0]) / int(size_mobile.split('x')[1])
                return form
            except Exception as exc:
                pass


class BoxAdminMixin(UserAdminMixin):
    fieldsets = (
        (_('general information'), {
            'fields': ('status', 'title', 'slug')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    prepopulated_fields = {'slug': ('title',)}

    def get_fieldsets(self, request, obj=None):
        if obj:
            try:
                parent = SectionSettings.objects.get(pk=obj.parent_id)
                return get_settings(parent.template_name, 'BOX', 'ADMIN')
            except Exception as e:
                pass

            try:
                return get_settings(obj.template_name, 'BOX', 'ADMIN')
            except Exception as exc:
                return settings.BOX_ADMIN_NO_PARENT

        return super().get_fieldsets(request, obj)

    def get_form(self, request, obj=None, **kwargs):
        form = super().get_form(request, obj, **kwargs)
        self.set_field_image_cropping(form, obj)            
        self.set_field_mobile_image_cropping(form, obj)
        return form
    
    def set_field_image_cropping(self, form, obj=None):
        if obj:
            try:
                parent = SectionSettings.objects.get(pk=obj.parent_id)
                size = get_settings(parent.template_name, 'BOX', 'CROPPING')
                form.base_fields['image_cropping'].widget.attrs['data-min-width'] = size.split('x')[0]
                form.base_fields['image_cropping'].widget.attrs['data-min-height'] = size.split('x')[1]
                form.base_fields['image_cropping'].widget.attrs['data-ratio'] = \
                    int(size.split('x')[0])/int(size.split('x')[1])
                return form
            except Exception as e:
                pass

            try:
                size = get_settings(obj.template_name, 'BOX', 'CROPPING')
                form.base_fields['image_cropping'].widget.attrs['data-min-width'] = size.split('x')[0]
                form.base_fields['image_cropping'].widget.attrs['data-min-height'] = size.split('x')[1]
                form.base_fields['image_cropping'].widget.attrs['data-ratio'] = \
                    int(size.split('x')[0])/int(size.split('x')[1])
                return form
            except Exception as exc:
                pass
            
    def set_field_mobile_image_cropping(self, form, obj=None):
        if obj:
            try:
                parent = SectionSettings.objects.get(pk=obj.parent_id)
                size_mobile = get_settings(parent.template_name, 'BOX', 'CROPPING_MOBILE')
                form.base_fields['mobile_image_cropping'].widget.attrs['data-min-width'] = size_mobile.split('x')[0]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-min-height'] = size_mobile.split('x')[1]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-ratio'] = \
                    int(size_mobile.split('x')[0]) / int(size_mobile.split('x')[1])
                return form
            except Exception as e:
                pass
    
            try:
                size_mobile = get_settings(obj.template_name, 'BOX', 'CROPPING_MOBILE')
                form.base_fields['mobile_image_cropping'].widget.attrs['data-min-width'] = size_mobile.split('x')[0]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-min-height'] = size_mobile.split('x')[1]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-ratio'] = \
                    int(size_mobile.split('x')[0]) / int(size_mobile.split('x')[1])
                return form
            except Exception as exc:
                pass


class ModelBoxAdminMixin(UserAdminMixin):
    fieldsets = (
        (_('general information'), {
            'fields': ('status', 'title', 'slug',)
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    filter_horizontal = ('tags',)
    prepopulated_fields = {'slug': ('title',)}

    def get_fieldsets(self, request, obj=None):
        if obj:
            try:
                parent = SectionSettings.objects.get(pk=obj.parent_id)
                return get_settings(parent.template_name, 'MODEL_BOX', 'ADMIN')
            except Exception as e:
                pass

            try:
                return get_settings(obj.template_name, 'MODEL_BOX', 'ADMIN')
            except Exception as exc:
                return settings.MODEL_BOX_ADMIN_NO_PARENT

        return super().get_fieldsets(request, obj)
    
    def get_form(self, request, obj=None, **kwargs):
        form = super().get_form(request, obj, **kwargs)
        self.set_field_image_cropping(form, obj)
        self.set_field_mobile_image_cropping(form, obj)
        return form

    def set_field_image_cropping(self, form, obj=None):
        if obj:
            try:
                parent = SectionSettings.objects.get(pk=obj.parent_id)
                size = get_settings(parent.template_name, 'MODEL_BOX', 'CROPPING')
                form.base_fields['image_cropping'].widget.attrs['data-min-width'] = size.split('x')[0]
                form.base_fields['image_cropping'].widget.attrs['data-min-height'] = size.split('x')[1]
                form.base_fields['image_cropping'].widget.attrs['data-ratio'] = \
                    int(size.split('x')[0]) / int(size.split('x')[1])
                return form
            except Exception as e:
                pass
    
            try:
                size = get_settings(obj.template_name, 'MODEL_BOX', 'CROPPING')
                form.base_fields['image_cropping'].widget.attrs['data-min-width'] = size.split('x')[0]
                form.base_fields['image_cropping'].widget.attrs['data-min-height'] = size.split('x')[1]
                form.base_fields['image_cropping'].widget.attrs['data-ratio'] = \
                    int(size.split('x')[0]) / int(size.split('x')[1])
                return form
            except Exception as exc:
                pass

    def set_field_mobile_image_cropping(self, form, obj=None):
        if obj:
            try:
                parent = SectionSettings.objects.get(pk=obj.parent_id)
                size_mobile = get_settings(parent.template_name, 'MODEL_BOX', 'CROPPING_MOBILE')
                form.base_fields['mobile_image_cropping'].widget.attrs['data-min-width'] = size_mobile.split('x')[0]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-min-height'] = size_mobile.split('x')[1]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-ratio'] = \
                    int(size_mobile.split('x')[0]) / int(size_mobile.split('x')[1])
                return form
            except Exception as e:
                pass
        
            try:
                size_mobile = get_settings(obj.template_name, 'MODEL_BOX', 'CROPPING_MOBILE')
                form.base_fields['mobile_image_cropping'].widget.attrs['data-min-width'] = size_mobile.split('x')[0]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-min-height'] = size_mobile.split('x')[1]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-ratio'] = \
                    int(size_mobile.split('x')[0]) / int(size_mobile.split('x')[1])
                return form
            except Exception as exc:
                pass


class FilterBoxAdminMixin(UserAdminMixin):
    fieldsets = (
        (_('general information'), {
            'fields': ('status', 'title', 'slug',)
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    prepopulated_fields = {'slug': ('title',)}

    def get_fieldsets(self, request, obj=None):
        if obj:
            try:
                parent = SectionSettings.objects.get(pk=obj.parent_id)
                return get_settings(parent.template_name, 'FILTER_BOX', 'ADMIN')
            except Exception as e:
                pass

            try:
                return get_settings(obj.template_name, 'FILTER_BOX', 'ADMIN')
            except Exception as exc:
                return settings.FILTER_BOX_ADMIN_NO_PARENT

        return super().get_fieldsets(request, obj)
    
    def get_form(self, request, obj=None, **kwargs):
        form = super().get_form(request, obj, **kwargs)
        self.set_field_image_cropping(form, obj)
        self.set_field_mobile_image_cropping(form, obj)
        return form

    def set_field_image_cropping(self, form, obj=None):
        if obj:
            try:
                parent = SectionSettings.objects.get(pk=obj.parent_id)
                size = get_settings(parent.template_name, 'FILTER_BOX', 'CROPPING')
                form.base_fields['image_cropping'].widget.attrs['data-min-width'] = size.split('x')[0]
                form.base_fields['image_cropping'].widget.attrs['data-min-height'] = size.split('x')[1]
                form.base_fields['image_cropping'].widget.attrs['data-ratio'] = \
                    int(size.split('x')[0]) / int(size.split('x')[1])
                return form
            except Exception as e:
                pass

            try:
                size = get_settings(obj.template_name, 'FILTER_BOX', 'CROPPING')
                form.base_fields['image_cropping'].widget.attrs['data-min-width'] = size.split('x')[0]
                form.base_fields['image_cropping'].widget.attrs['data-min-height'] = size.split('x')[1]
                form.base_fields['image_cropping'].widget.attrs['data-ratio'] = \
                    int(size.split('x')[0]) / int(size.split('x')[1])
                return form
            except Exception as exc:
                pass

    def set_field_mobile_image_cropping(self, form, obj=None):
        if obj:
            try:
                parent = SectionSettings.objects.get(pk=obj.parent_id)
                size_mobile = settings.FILTER_BOX_CROPPING_MOBILE[parent.template_name]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-min-width'] = size_mobile.split('x')[0]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-min-height'] = size_mobile.split('x')[1]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-ratio'] = \
                    int(size_mobile.split('x')[0]) / int(size_mobile.split('x')[1])
                return form
            except Exception as e:
                pass
    
            try:
                size_mobile = settings.FILTER_BOX_CROPPING_MOBILE[obj.template_name]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-min-width'] = size_mobile.split('x')[0]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-min-height'] = size_mobile.split('x')[1]
                form.base_fields['mobile_image_cropping'].widget.attrs['data-ratio'] = \
                    int(size_mobile.split('x')[0]) / int(size_mobile.split('x')[1])
                return form
            except Exception as exc:
                pass
            

class LabelTagAdmin(admin.TabularInline):
    model = LabelTagSettings
    extra = 0
    fields = ('status', 'label', 'tag', 'ordering', 'classes')
    fk_name = 'plugin'
